@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import Dict, List, Optional
 
 from pydantic import Extra
 
@@ -49,3 +49,29 @@ class Event(Base):
 
 class Result(Base):
     event: Optional[Event] = None
+
+
+class Broken(Base):
+    foo: Optional[str] = None
+    bar: Optional[int] = None
+
+
+class Failing(Base):
+    pass
+
+    class Config:
+        extra = Extra.allow
+
+
+class Test(Base):
+    broken: Optional[Dict[str, Broken]] = None
+    failing: Optional[Dict[str, Failing]] = {}
+
+
+class Tags(Base):
+    __root__: List[str]
+
+
+class FileSetUpload(Base):
+    task_id: Optional[str] = None
+    tags: Dict[str, Tags]
